@@ -1,6 +1,6 @@
 /*
  * kit : Useful R Functions Implemented in C
- * Copyright (C) 2020-2024  Morgan Jacob
+ * Copyright (C) 2020-2025  Morgan Jacob
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  */
 
 SEXP dupLenR(SEXP x) {
-  if (isFrame(x)) {
+  if (isDataFrame(x)) {
     SEXP ans = PROTECT(dupLenDataFrameR(x));
     UNPROTECT(1);
     return ans;
